@@ -1,4 +1,4 @@
-﻿(function (window) {
+﻿define(['jQuery'], function ($) {
 
     function processForgotPasswordResult(page, result) {
 
@@ -58,4 +58,4 @@
         $('form', page).off('submit', onSubmit).on('submit', onSubmit);
     });
 
-})(window);
\ No newline at end of file
+});
\ No newline at end of file
