@@ -1,4 +1,4 @@
-﻿(function ($, document, window) {
+﻿define(['appSettings', 'appStorage', 'libraryBrowser', 'jQuery'], function (appSettings, appStorage, LibraryBrowser, $) {
 
     var showOverlayTimeout;
 
@@ -196,7 +196,7 @@
 
     function onMoreButtonClick() {
 
-        var card = $(this).parents('.card')[0];
+        var card = parentWithClass(this, 'card');
 
         showContextMenu(card, {
             showPlayOptions: false
@@ -338,7 +338,7 @@
                     }
                 }
 
-                if (mediaType == 'Video' && AppInfo.supportsExternalPlayers && AppSettings.enableExternalPlayers()) {
+                if (mediaType == 'Video' && AppInfo.supportsExternalPlayers && appSettings.enableExternalPlayers()) {
                     items.push({
                         name: Globalize.translate('ButtonPlayExternalPlayer'),
                         id: 'externalplayer',
@@ -468,7 +468,10 @@
                                 });
                                 break;
                             case 'playlist':
-                                PlaylistManager.showPanel([itemId]);
+                                require(['playlistManager'], function (playlistManager) {
+
+                                    playlistManager.showPanel([itemId]);
+                                });
                                 break;
                             case 'delete':
                                 LibraryBrowser.deleteItems([itemId]);
@@ -519,7 +522,7 @@
                                 MediaController.play(itemId);
                                 break;
                             case 'playallfromhere':
-                                playAllFromHere(index, $(card).parents('.itemsContainer'), 'play');
+                                playAllFromHere(index, parentWithClass(card, 'itemsContainer'), 'play');
                                 break;
                             case 'queue':
                                 MediaController.queue(itemId);
@@ -536,14 +539,16 @@
                                 });
                                 break;
                             case 'queueallfromhere':
-                                playAllFromHere(index, $(card).parents('.itemsContainer'), 'queue');
+                                playAllFromHere(index, parentWithClass(card, 'itemsContainer'), 'queue');
                                 break;
                             case 'sync':
-                                SyncManager.showMenu({
-                                    items: [
-                                    {
-                                        Id: itemId
-                                    }]
+                                require(['syncDialog'], function (syncDialog) {
+                                    syncDialog.showMenu({
+                                        items: [
+                                        {
+                                            Id: itemId
+                                        }]
+                                    });
                                 });
                                 break;
                             case 'editsubtitles':
@@ -710,7 +715,7 @@
         return elem;
     }
 
-    $.fn.createCardMenus = function (options) {
+    LibraryBrowser.createCardMenus = function (curr, options) {
 
         var preventHover = false;
 
@@ -797,32 +802,37 @@
             preventHover = true;
         }
 
+        curr.removeEventListener('click', onCardClick);
+        curr.addEventListener('click', onCardClick);
+
+        if (AppInfo.isTouchPreferred) {
+
+            curr.removeEventListener('contextmenu', disableEvent);
+            curr.addEventListener('contextmenu', disableEvent);
+        }
+        else {
+            curr.removeEventListener('contextmenu', onContextMenu);
+            curr.addEventListener('contextmenu', onContextMenu);
+
+            curr.removeEventListener('mouseenter', onHoverIn);
+            curr.addEventListener('mouseenter', onHoverIn, true);
+
+            curr.removeEventListener('mouseleave', onHoverOut);
+            curr.addEventListener('mouseleave', onHoverOut, true);
+
+            curr.removeEventListener("touchstart", preventTouchHover);
+            curr.addEventListener("touchstart", preventTouchHover);
+        }
+
+        initTapHoldMenus(curr);
+    };
+
+    $.fn.createCardMenus = function (options) {
+
         for (var i = 0, length = this.length; i < length; i++) {
 
             var curr = this[i];
-            curr.removeEventListener('click', onCardClick);
-            curr.addEventListener('click', onCardClick);
-
-            if (AppInfo.isTouchPreferred) {
-
-                curr.removeEventListener('contextmenu', disableEvent);
-                curr.addEventListener('contextmenu', disableEvent);
-            }
-            else {
-                curr.removeEventListener('contextmenu', onContextMenu);
-                curr.addEventListener('contextmenu', onContextMenu);
-
-                curr.removeEventListener('mouseenter', onHoverIn);
-                curr.addEventListener('mouseenter', onHoverIn, true);
-
-                curr.removeEventListener('mouseleave', onHoverOut);
-                curr.addEventListener('mouseleave', onHoverOut, true);
-
-                curr.removeEventListener("touchstart", preventTouchHover);
-                curr.addEventListener("touchstart", preventTouchHover);
-            }
-
-            initTapHoldMenus(curr);
+            LibraryBrowser.createCardMenus(curr, options);
         }
 
         return this;
@@ -874,7 +884,7 @@
 
     function showTapHoldHelp(element) {
 
-        var page = $(element).parents('.page')[0];
+        var page = parentWithClass(element, 'page');
 
         if (!page) {
             return;
@@ -1164,17 +1174,20 @@
                                 hideSelections();
                                 break;
                             case 'playlist':
-                                PlaylistManager.showPanel(items);
-                                hideSelections();
+                                require(['playlistManager'], function (playlistManager) {
+
+                                    playlistManager.showPanel(items);
+                                    hideSelections();
+                                });
                                 break;
                             case 'delete':
                                 LibraryBrowser.deleteItems(items).then(function () {
-                                    Dashboard.navigate('index.html');
+                                    Dashboard.navigate('home.html');
                                 });
                                 hideSelections();
                                 break;
                             case 'groupvideos':
-                                combineVersions($($.mobile.activePage)[0], items);
+                                combineVersions($.mobile.activePage, items);
                                 break;
                             case 'refresh':
                                 items.map(function (itemId) {
@@ -1193,12 +1206,14 @@
                                 hideSelections();
                                 break;
                             case 'sync':
-                                SyncManager.showMenu({
-                                    items: items.map(function (i) {
-                                        return {
-                                            Id: i
-                                        };
-                                    })
+                                require(['syncDialog'], function (syncDialog) {
+                                    syncDialog.showMenu({
+                                        items: items.map(function (i) {
+                                            return {
+                                                Id: i
+                                            };
+                                        })
+                                    });
                                 });
                                 hideSelections();
                                 break;
@@ -1226,9 +1241,9 @@
 
         var msg = Globalize.translate('MessageTheSelectedItemsWillBeGrouped');
 
-        Dashboard.confirm(msg, Globalize.translate('HeaderGroupVersions'), function (confirmResult) {
+        require(['confirm'], function (confirm) {
 
-            if (confirmResult) {
+            confirm(msg, Globalize.translate('HeaderGroupVersions')).then(function () {
 
                 Dashboard.showLoadingMsg();
 
@@ -1243,7 +1258,7 @@
                     hideSelections();
                     $('.itemsContainer', page).trigger('needsrefresh');
                 });
-            }
+            });
         });
     }
 
@@ -1276,7 +1291,7 @@
 
             index = elemWithAttributes.getAttribute('data-index');
 
-            itemsContainer = $(elem).parents('.itemsContainer');
+            itemsContainer = parentWithClass(elem, 'itemsContainer');
 
             playAllFromHere(index, itemsContainer, 'play');
         }
@@ -1319,6 +1334,41 @@
         });
     }
 
+    function showSyncButtonsPerUser(page) {
+
+        var apiClient = window.ApiClient;
+
+        if (!apiClient || !apiClient.getCurrentUserId()) {
+            return;
+        }
+
+        Dashboard.getCurrentUser().then(function (user) {
+
+            var item = {
+                SupportsSync: true
+            };
+
+            if (LibraryBrowser.enableSync(item, user)) {
+                $('.categorySyncButton', page).removeClass('hide');
+            } else {
+                $('.categorySyncButton', page).addClass('hide');
+            }
+        });
+    }
+
+    function onCategorySyncButtonClick(page, button) {
+
+        var category = button.getAttribute('data-category');
+        var parentId = LibraryMenu.getTopParentId();
+
+        require(['syncDialog'], function (syncDialog) {
+            syncDialog.showMenu({
+                ParentId: parentId,
+                Category: category
+            });
+        });
+    }
+
     pageClassOn('pageinit', "libraryPage", function () {
 
         var page = this;
@@ -1327,9 +1377,23 @@
 
         var itemsContainers = page.querySelectorAll('.itemsContainer:not(.noautoinit)');
         for (var i = 0, length = itemsContainers.length; i < length; i++) {
-            $(itemsContainers[i]).createCardMenus();
+            LibraryBrowser.createCardMenus(itemsContainers[i]);
         }
 
+        $('.categorySyncButton', page).on('click', function () {
+
+            onCategorySyncButtonClick(page, this);
+        });
+
+    });
+
+    pageClassOn('pageshow', "libraryPage", function () {
+
+        var page = this;
+
+        if (!Dashboard.isServerlessPage()) {
+            showSyncButtonsPerUser(page);
+        }
     });
 
     pageClassOn('pagebeforehide', "libraryPage", function () {
@@ -1394,7 +1458,7 @@
             if (mediaType == 'Video') {
                 this.setAttribute('data-positionticks', (userData.PlaybackPositionTicks || 0));
 
-                if ($(this).hasClass('card')) {
+                if (this.classList.contains('card')) {
                     renderUserDataChanges(this, userData);
                 }
             }
@@ -1437,4 +1501,4 @@
     Events.on(ConnectionManager, 'localusersignedin', clearRefreshTimes);
     Events.on(ConnectionManager, 'localusersignedout', clearRefreshTimes);
 
-})(jQuery, document, window);
\ No newline at end of file
+});
\ No newline at end of file
