@@ -1,4 +1,4 @@
-﻿(function (window, document, $, devicePixelRatio) {
+﻿define(['imageLoader', 'jQuery', 'paper-icon-button', 'paper-button', 'emby-icons'], function (imageLoader, $) {
 
     function renderHeader() {
 
@@ -29,13 +29,11 @@
             html += '</div>';
         }
 
-        html += '<paper-icon-button icon="mic" class="headerButton headerButtonRight headerVoiceButton hide" onclick="VoiceInputManager.startListening();"></paper-icon-button>';
+        html += '<paper-icon-button icon="mic" class="headerButton headerButtonRight headerVoiceButton hide"></paper-icon-button>';
 
         html += '<paper-button class="headerButton headerButtonRight btnNotifications subdued" type="button" title="Notifications"><div class="btnNotificationsInner">0</div></paper-button>';
 
-        if (!showUserAtTop()) {
-            html += '<paper-icon-button icon="person" class="headerButton headerButtonRight headerUserButton" onclick="return Dashboard.showUserFlyout(this);"></paper-icon-button>';
-        }
+        html += '<paper-icon-button icon="person" class="headerButton headerButtonRight headerUserButton"></paper-icon-button>';
 
         if (!browserInfo.mobile && !Dashboard.isConnectMode()) {
             html += '<paper-icon-button icon="settings" class="headerButton headerButtonRight dashboardEntryHeaderButton" onclick="return LibraryMenu.onSettingsClicked(event);"></paper-icon-button>';
@@ -50,9 +48,7 @@
 
         document.body.appendChild(viewMenuBar);
 
-        require(['imageLoader'], function (imageLoader) {
-            imageLoader.lazyChildren(document.querySelector('.viewMenuBar'));
-        });
+        imageLoader.lazyChildren(document.querySelector('.viewMenuBar'));
 
         document.dispatchEvent(new CustomEvent("headercreated", {}));
         bindMenuEvents();
@@ -76,35 +72,26 @@
         var hasImage;
 
         if (user && user.name) {
-            if (user.imageUrl && AppInfo.enableUserImage) {
+            if (user.imageUrl) {
 
                 var userButtonHeight = 26;
 
                 var url = user.imageUrl;
 
                 if (user.supportsImageParams) {
-                    url += "&height=" + (userButtonHeight * Math.max(devicePixelRatio || 1, 2));
+                    url += "&height=" + (userButtonHeight * Math.max(window.devicePixelRatio || 1, 2));
                 }
 
                 if (headerUserButton) {
-                    headerUserButton.icon = null;
-                    headerUserButton.src = url;
-                    headerUserButton.classList.add('headerUserButtonRound');
+                    updateHeaderUserButton(headerUserButton, url, null);
                     hasImage = true;
                 }
             }
         }
 
         if (headerUserButton && !hasImage) {
-            headerUserButton.icon = 'person';
-            headerUserButton.src = null;
-            headerUserButton.classList.remove('headerUserButtonRound');
 
-            // Looks like a bug in paper-icon-button that this doesn't get removed
-            var headerUserButtonImg = headerUserButton.querySelector('img');
-            if (headerUserButtonImg) {
-                headerUserButtonImg.parentNode.removeChild(headerUserButtonImg);
-            }
+            updateHeaderUserButton(headerUserButton, null, 'person');
         }
         if (user) {
             updateLocalUser(user.localUser);
@@ -113,6 +100,30 @@
         requiresUserRefresh = false;
     }
 
+    function updateHeaderUserButton(headerUserButton, src, icon) {
+
+        var oldButton = headerUserButton;
+
+        // There seems to be a bug in paper-icon-button where it doesn't refresh it's display after switching between icon and src image
+        // So work around that by just replacing the element altogether
+
+        var headerUserButton = document.createElement('paper-icon-button');
+        headerUserButton.className = oldButton.className;
+        headerUserButton.addEventListener('click', onHeaderUserButtonClick);
+
+        if (src) {
+            headerUserButton.classList.add('headerUserButtonRound');
+            headerUserButton.src = src;
+        } else if (icon) {
+            headerUserButton.classList.remove('headerUserButtonRound');
+            headerUserButton.icon = icon;
+        } else {
+            headerUserButton.classList.remove('headerUserButtonRound');
+        }
+
+        oldButton.parentNode.replaceChild(headerUserButton, oldButton);
+    }
+
     function updateLocalUser(user) {
 
         var header = document.querySelector('.viewMenuBar');
@@ -136,9 +147,9 @@
                 }
             }
 
-            requirejs(['voice/voice'], function () {
+            require(['voice/voice'], function (voice) {
 
-                if (VoiceInputManager.isSupported()) {
+                if (voice.isSupported()) {
                     header.querySelector('.headerVoiceButton').classList.remove('hide');
                 } else {
                     header.querySelector('.headerVoiceButton').classList.add('hide');
@@ -159,12 +170,22 @@
         }
     }
 
+    function showVoice() {
+        require(['voice/voice'], function (voice) {
+            voice.startListening();
+        });
+    }
+
+    function onHeaderUserButtonClick(e) {
+        Dashboard.showUserFlyout(e.target);
+    }
+
     function bindMenuEvents() {
 
         var mainDrawerButton = document.querySelector('.mainDrawerButton');
 
         if (mainDrawerButton) {
-            mainDrawerButton.addEventListener('click', openMainDrawer);
+            mainDrawerButton.addEventListener('click', toggleMainDrawer);
         }
 
         var headerBackButton = document.querySelector('.headerBackButton');
@@ -172,6 +193,16 @@
             headerBackButton.addEventListener('click', onBackClick);
         }
 
+        var headerVoiceButton = document.querySelector('.headerVoiceButton');
+        if (headerVoiceButton) {
+            headerVoiceButton.addEventListener('click', showVoice);
+        }
+
+        var headerUserButton = document.querySelector('.headerUserButton');
+        if (headerUserButton) {
+            headerUserButton.addEventListener('click', onHeaderUserButtonClick);
+        }
+
         var viewMenuBar = document.querySelector(".viewMenuBar");
         initHeadRoom(viewMenuBar);
 
@@ -190,9 +221,19 @@
     var requiresUserRefresh = true;
     var lastOpenTime = new Date().getTime();
 
-    function openMainDrawer() {
+    function toggleMainDrawer() {
 
         var drawerPanel = document.querySelector('.mainDrawerPanel');
+        if (drawerPanel.selected == 'drawer') {
+            closeMainDrawer(drawerPanel);
+        } else {
+            openMainDrawer(drawerPanel);
+        }
+    }
+
+    function openMainDrawer(drawerPanel) {
+
+        drawerPanel = drawerPanel || document.querySelector('.mainDrawerPanel');
         drawerPanel.openDrawer();
         lastOpenTime = new Date().getTime();
     }
@@ -203,7 +244,7 @@
             document.body.classList.add('bodyWithPopupOpen');
         }
 
-        var pageElem = $($.mobile.activePage)[0];
+        var pageElem = $.mobile.activePage;
 
         if (requiresDrawerRefresh || requiresDashboardDrawerRefresh) {
 
@@ -235,9 +276,10 @@
 
         document.querySelector('.mainDrawerPanel #drawer').classList.add('verticalScrollingDrawer');
     }
-    function closeMainDrawer() {
+    function closeMainDrawer(drawerPanel) {
 
-        document.querySelector('.mainDrawerPanel').closeDrawer();
+        drawerPanel = drawerPanel || document.querySelector('.mainDrawerPanel');
+        drawerPanel.closeDrawer();
     }
     function onMainDrawerSelect(e) {
 
@@ -277,44 +319,14 @@
 
         var html = '';
 
-        var userAtTop = showUserAtTop();
+        var homeHref = window.ApiClient ? 'home.html' : 'selectserver.html?showuser=1';
 
-        var homeHref = window.ApiClient ? 'index.html' : 'selectserver.html?showuser=1';
+        html += '<div style="margin-top:5px;"></div>';
 
-        var hasUserImage = user.imageUrl && AppInfo.enableUserImage;
-
-        if (userAtTop) {
-
-            html += '<div class="drawerUserPanel">';
-
-            var imgWidth = 40;
-
-            if (hasUserImage) {
-                var url = user.imageUrl;
-                if (user.supportsImageParams) {
-                    url += "&width=" + (imgWidth * Math.max(devicePixelRatio || 1, 2));
-                    html += '<div class="lazy drawerUserPanelUserImage" data-src="' + url + '" style="width:' + imgWidth + 'px;height:' + imgWidth + 'px;"></div>';
-                }
-            } else {
-                html += '<div class="drawerUserPanelUserImage"><iron-icon icon="person" style="width:' + imgWidth + 'px;height:' + imgWidth + 'px;"></iron-icon></div>';
-            }
-
-            html += '<div class="drawerUserPanelUserName">';
-            html += user.name;
-            html += '</div>';
-
-            html += '</div>';
-
-            html += '<a class="sidebarLink lnkMediaFolder" data-itemid="remote" href="index.html" onclick="return LibraryMenu.onLinkClicked(event, this);"><iron-icon icon="home" class="sidebarLinkIcon" style="color:#2196F3;"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonHome') + '</span></a>';
-
-        } else {
-            html += '<div style="margin-top:5px;"></div>';
-
-            html += '<a class="lnkMediaFolder sidebarLink" href="' + homeHref + '" onclick="return LibraryMenu.onLinkClicked(event, this);">';
-            html += '<div style="background-image:url(\'css/images/mblogoicon.png\');width:' + 28 + 'px;height:' + 28 + 'px;background-size:contain;background-repeat:no-repeat;background-position:center center;border-radius:1000px;vertical-align:middle;margin:0 1.6em 0 1.5em;display:inline-block;"></div>';
-            html += Globalize.translate('ButtonHome');
-            html += '</a>';
-        }
+        html += '<a class="lnkMediaFolder sidebarLink" href="' + homeHref + '" onclick="return LibraryMenu.onLinkClicked(event, this);">';
+        html += '<div style="background-image:url(\'css/images/mblogoicon.png\');width:' + 28 + 'px;height:' + 28 + 'px;background-size:contain;background-repeat:no-repeat;background-position:center center;border-radius:1000px;vertical-align:middle;margin:0 1.6em 0 1.5em;display:inline-block;"></div>';
+        html += Globalize.translate('ButtonHome');
+        html += '</a>';
 
         html += '<a class="sidebarLink lnkMediaFolder" data-itemid="remote" href="nowplaying.html" onclick="return LibraryMenu.onLinkClicked(event, this);"><iron-icon icon="tablet-android" class="sidebarLinkIcon" style="color:#673AB7;"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonRemote') + '</span></a>';
 
@@ -375,7 +387,7 @@
 
         html += '<div class="sidebarDivider"></div>';
 
-        if (user.localUser && showUserAtTop()) {
+        if (user.localUser && (AppInfo.isNativeApp && browserInfo.android)) {
             html += '<a class="sidebarLink lnkMediaFolder lnkMySettings" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mypreferencesmenu.html?userId=' + user.localUser.Id + '"><iron-icon icon="settings" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSettings') + '</span></a>';
         }
 
@@ -385,7 +397,7 @@
             html += '<a class="sidebarLink lnkMediaFolder" data-itemid="selectserver" onclick="return LibraryMenu.onLinkClicked(event, this);" href="selectserver.html?showuser=1"><iron-icon icon="wifi" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSelectServer') + '</span></a>';
         }
 
-        if (showUserAtTop()) {
+        if (user.localUser) {
             html += '<a class="sidebarLink lnkMediaFolder" data-itemid="logout" onclick="return LibraryMenu.onLogoutClicked(this);" href="#"><iron-icon icon="lock" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSignOut') + '</span></a>';
         }
 
@@ -423,7 +435,7 @@
                     view.icon = 'live-tv';
                     view.onclick = "LibraryBrowser.showTab('livetv.html', 0);";
 
-                    var guideView = $.extend({}, view);
+                    var guideView = Object.assign({}, view);
                     guideView.Name = Globalize.translate('ButtonGuide');
                     guideView.ImageTags = {};
                     guideView.icon = 'dvr';
@@ -431,7 +443,7 @@
                     guideView.onclick = "LibraryBrowser.showTab('livetv.html', 1);";
                     list.push(guideView);
 
-                    var recordedTvView = $.extend({}, view);
+                    var recordedTvView = Object.assign({}, view);
                     recordedTvView.Name = Globalize.translate('ButtonRecordedTv');
                     recordedTvView.ImageTags = {};
                     recordedTvView.icon = 'video-library';
@@ -445,13 +457,25 @@
         });
     }
 
+    function showBySelector(selector, show) {
+        var elem = document.querySelector(selector);
+
+        if (elem) {
+            if (show) {
+                elem.classList.remove('hide');
+            } else {
+                elem.classList.add('hide');
+            }
+        }
+    }
+
     function updateLibraryMenu(user) {
 
         if (!user) {
 
-            $('.adminMenuOptions').addClass('hide');
-            $('.lnkMySync').addClass('hide');
-            $('.userMenuOptions').addClass('hide');
+            showBySelector('.adminMenuOptions', false);
+            showBySelector('.lnkMySync', false);
+            showBySelector('.userMenuOptions', false);
             return;
         }
 
@@ -529,26 +553,26 @@
             libraryMenuOptions.innerHTML = html;
             var elem = libraryMenuOptions;
 
-            $('.sidebarLink', elem).off('click', onSidebarLinkClick).on('click', onSidebarLinkClick);
+            var sidebarLinks = elem.querySelectorAll('.sidebarLink');
+            for (var i = 0, length = sidebarLinks.length; i < length; i++) {
+                sidebarLinks[i].removeEventListener('click', onSidebarLinkClick);
+                sidebarLinks[i].addEventListener('click', onSidebarLinkClick);
+            }
         });
 
         if (user.Policy.IsAdministrator) {
-            $('.adminMenuOptions').removeClass('hide');
+            showBySelector('.adminMenuOptions', true);
         } else {
-            $('.adminMenuOptions').addClass('hide');
+            showBySelector('.adminMenuOptions', false);
         }
 
         if (user.Policy.EnableSync) {
-            $('.lnkMySync').removeClass('hide');
+            showBySelector('.lnkMySync', true);
         } else {
-            $('.lnkMySync').addClass('hide');
+            showBySelector('.lnkMySync', false);
         }
     }
 
-    function showUserAtTop() {
-        return AppInfo.isNativeApp;
-    }
-
     var requiresLibraryMenuRefresh = false;
 
     function onManageServerClicked() {
@@ -615,7 +639,7 @@
         },
 
         onHardwareMenuButtonClick: function () {
-            openMainDrawer();
+            toggleMainDrawer();
         },
 
         onSettingsClicked: function (event) {
@@ -821,11 +845,11 @@
         updateTabLinks(page);
     });
 
-    pageClassOn('pageshow', 'page', function () {
+    pageClassOn('pageshow', 'page', function (e) {
 
         var page = this;
 
-        if (!NavHelper.isBack()) {
+        if (!e.detail.isRestored) {
             // Scroll back up so in case vertical scroll was messed with
             window.scrollTo(0, 0);
         }
@@ -904,7 +928,7 @@
             return;
         }
 
-        requirejs(["headroom"], function () {
+        require(["headroom"], function () {
 
             // construct an instance of Headroom, passing the element
             var headroom = new Headroom(elem, {
@@ -968,27 +992,4 @@
 
     setDrawerClass();
 
-})(window, document, jQuery, window.devicePixelRatio);
-
-(function () {
-
-    var isCurrentNavBack = false;
-
-    window.addEventListener("navigate", function (e) {
-
-        var data = e.detail.state || {};
-        var direction = data.direction;
-
-        isCurrentNavBack = direction == 'back';
-    });
-
-    function isBack() {
-
-        return isCurrentNavBack;
-    }
-
-    window.NavHelper = {
-        isBack: isBack
-    };
-
-})();
\ No newline at end of file
+});
\ No newline at end of file
