@@ -1,4 +1,4 @@
-﻿(function ($, document) {
+﻿define(['jQuery'], function ($) {
 
     var data = {};
     function getPageData(context) {
@@ -250,4 +250,4 @@
         }
     };
 
-})(jQuery, document);
\ No newline at end of file
+});
\ No newline at end of file
